@@ -17,7 +17,7 @@ func versionCmd() *cobra.Command {
 		Use:   "version",
 		Short: "Print version/build info",
 		Long:  "Print version/build information",
-		Run: func(cmd *cobra.Command, args []string) {
+		Run: func(*cobra.Command, []string) {
 			printVersion(short)
 		},
 	}
@@ -44,8 +44,8 @@ func printVersion(short bool) {
 
 func printTuple(fmat, section, value string, outputColor color.Paint) {
 	if outputColor != -1 {
-		fmt.Fprintf(out, fmat, color.Colorize(section+":", outputColor), value)
+		_, _ = fmt.Fprintf(out, fmat, color.Colorize(section+":", outputColor), value)
 		return
 	}
-	fmt.Fprintf(out, fmat, section, value)
+	_, _ = fmt.Fprintf(out, fmat, section, value)
 }
