@@ -8,14 +8,17 @@ import (
 	"log/slog"
 	"path"
 	"strings"
+	"sync"
 
 	"github.com/derailed/k9s/internal/slogs"
 	"github.com/fvbommel/sortorder"
+	"gopkg.in/yaml.v3"
+	apiext "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
 
-var NoGVR = GVR{}
+var NoGVR = new(GVR)
 
 // GVR represents a kubernetes resource schema as a string.
 // Format is group/version/resources:subresource.
@@ -23,12 +26,39 @@ type GVR struct {
 	raw, g, v, r, sr string
 }
 
-// NewGVR builds a new gvr from a group, version, resource.
-func NewGVR(gvr string) GVR {
-	var g, v, r, sr string
+type gvrCache struct {
+	data map[string]*GVR
+	sync.RWMutex
+}
 
-	tokens := strings.Split(gvr, ":")
-	raw := gvr
+func (c *gvrCache) add(gvr *GVR) {
+	if c.get(gvr.String()) == nil {
+		c.Lock()
+		c.data[gvr.String()] = gvr
+		c.Unlock()
+	}
+}
+
+func (c *gvrCache) get(gvrs string) *GVR {
+	c.RLock()
+	defer c.RUnlock()
+
+	if gvr, ok := c.data[gvrs]; ok {
+		return gvr
+	}
+
+	return nil
+}
+
+var gvrsCache = gvrCache{
+	data: make(map[string]*GVR),
+}
+
+// NewGVR builds a new gvr from a group, version, resource.
+func NewGVR(s string) *GVR {
+	raw := s
+	tokens := strings.Split(s, ":")
+	var g, v, r, sr string
 	if len(tokens) == 2 {
 		raw, sr = tokens[0], tokens[1]
 	}
@@ -41,34 +71,66 @@ func NewGVR(gvr string) GVR {
 	case 1:
 		r = tokens[0]
 	default:
-		slog.Error("GVR init failed!", slogs.Error, fmt.Errorf("can't parse GVR %q", gvr))
+		slog.Error("GVR init failed!", slogs.Error, fmt.Errorf("can't parse GVR %q", s))
 	}
 
-	return GVR{raw: gvr, g: g, v: v, r: r, sr: sr}
+	gvr := GVR{raw: s, g: g, v: v, r: r, sr: sr}
+	if cgvr := gvrsCache.get(gvr.String()); cgvr != nil {
+		return cgvr
+	}
+	gvrsCache.add(&gvr)
+
+	return &gvr
+}
+
+func (g *GVR) IsCommand() bool {
+	return !g.IsK8sRes()
+}
+
+func (g *GVR) IsK8sRes() bool {
+	return g != nil && ((!strings.Contains(g.raw, " ") && strings.Contains(g.raw, "/") && !strings.Contains(g.raw, " /")) || reservedGVRs.Has(g))
+}
+
+// WithSubResource builds a new gvr with a sub resource.
+func (g *GVR) WithSubResource(sub string) *GVR {
+	return NewGVR(g.String() + ":" + sub)
 }
 
 // NewGVRFromMeta builds a gvr from resource metadata.
-func NewGVRFromMeta(a metav1.APIResource) GVR {
-	return GVR{
-		raw: path.Join(a.Group, a.Version, a.Name),
-		g:   a.Group,
-		v:   a.Version,
-		r:   a.Name,
+func NewGVRFromMeta(a *metav1.APIResource) *GVR {
+	return NewGVR(path.Join(a.Group, a.Version, a.Name))
+}
+
+// NewGVRFromCRD builds a gvr from a custom resource definition.
+func NewGVRFromCRD(crd *apiext.CustomResourceDefinition) map[*GVR]*apiext.CustomResourceDefinitionVersion {
+	mm := make(map[*GVR]*apiext.CustomResourceDefinitionVersion, len(crd.Spec.Versions))
+	for _, v := range crd.Spec.Versions {
+		if v.Served && !v.Deprecated {
+			gvr := NewGVRFromMeta(&metav1.APIResource{
+				Kind:    crd.Spec.Names.Kind,
+				Group:   crd.Spec.Group,
+				Name:    crd.Spec.Names.Plural,
+				Version: v.Name,
+			})
+			mm[gvr] = &v
+		}
 	}
+
+	return mm
 }
 
 // FromGVAndR builds a gvr from a group/version and resource.
-func FromGVAndR(gv, r string) GVR {
+func FromGVAndR(gv, r string) *GVR {
 	return NewGVR(path.Join(gv, r))
 }
 
 // FQN returns a fully qualified resource name.
-func (g GVR) FQN(n string) string {
+func (g *GVR) FQN(n string) string {
 	return path.Join(g.AsResourceName(), n)
 }
 
 // AsResourceName returns a resource . separated descriptor in the shape of kind.version.group.
-func (g GVR) AsResourceName() string {
+func (g *GVR) AsResourceName() string {
 	if g.g == "" {
 		return g.r
 	}
@@ -77,17 +139,17 @@ func (g GVR) AsResourceName() string {
 }
 
 // SubResource returns a sub resource if available.
-func (g GVR) SubResource() string {
+func (g *GVR) SubResource() string {
 	return g.sr
 }
 
 // String returns gvr as string.
-func (g GVR) String() string {
+func (g *GVR) String() string {
 	return g.raw
 }
 
 // GV returns the group version scheme representation.
-func (g GVR) GV() schema.GroupVersion {
+func (g *GVR) GV() schema.GroupVersion {
 	return schema.GroupVersion{
 		Group:   g.g,
 		Version: g.v,
@@ -95,7 +157,7 @@ func (g GVR) GV() schema.GroupVersion {
 }
 
 // GVK returns a full schema representation.
-func (g GVR) GVK() schema.GroupVersionKind {
+func (g *GVR) GVK() schema.GroupVersionKind {
 	return schema.GroupVersionKind{
 		Group:   g.G(),
 		Version: g.V(),
@@ -104,7 +166,7 @@ func (g GVR) GVK() schema.GroupVersionKind {
 }
 
 // GVR returns a full schema representation.
-func (g GVR) GVR() schema.GroupVersionResource {
+func (g *GVR) GVR() schema.GroupVersionResource {
 	return schema.GroupVersionResource{
 		Group:    g.G(),
 		Version:  g.V(),
@@ -113,7 +175,7 @@ func (g GVR) GVR() schema.GroupVersionResource {
 }
 
 // GVSub returns group vervion sub path.
-func (g GVR) GVSub() string {
+func (g *GVR) GVSub() string {
 	if g.G() == "" {
 		return g.V()
 	}
@@ -122,7 +184,7 @@ func (g GVR) GVSub() string {
 }
 
 // GR returns a full schema representation.
-func (g GVR) GR() *schema.GroupResource {
+func (g *GVR) GR() *schema.GroupResource {
 	return &schema.GroupResource{
 		Group:    g.G(),
 		Resource: g.R(),
@@ -130,32 +192,45 @@ func (g GVR) GR() *schema.GroupResource {
 }
 
 // V returns the resource version.
-func (g GVR) V() string {
+func (g *GVR) V() string {
 	return g.v
 }
 
 // RG returns the resource and group.
-func (g GVR) RG() (string, string) {
+func (g *GVR) RG() (resource, group string) {
 	return g.r, g.g
 }
 
 // R returns the resource name.
-func (g GVR) R() string {
+func (g *GVR) R() string {
 	return g.r
 }
 
 // G returns the resource group name.
-func (g GVR) G() string {
+func (g *GVR) G() string {
 	return g.g
 }
 
 // IsDecodable checks if the k8s resource has a decodable view
-func (g GVR) IsDecodable() bool {
-	return g.GVK().Kind == "secrets"
+func (g *GVR) IsDecodable() bool {
+	return g == SecGVR
+}
+
+var _ = yaml.Marshaler((*GVR)(nil))
+var _ = yaml.Unmarshaler((*GVR)(nil))
+
+func (g *GVR) MarshalYAML() (any, error) {
+	return g.String(), nil
+}
+
+func (g *GVR) UnmarshalYAML(n *yaml.Node) error {
+	*g = *NewGVR(n.Value)
+
+	return nil
 }
 
 // GVRs represents a collection of gvr.
-type GVRs []GVR
+type GVRs []*GVR
 
 // Len returns the list size.
 func (g GVRs) Len() int {
