@@ -20,9 +20,6 @@ import (
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
-	"k8s.io/apimachinery/pkg/util/strategicpatch"
-	"k8s.io/kubectl/pkg/polymorphichelpers"
-	"k8s.io/kubectl/pkg/scheme"
 )
 
 var (
@@ -42,7 +39,7 @@ type StatefulSet struct {
 }
 
 // ListImages lists container images.
-func (s *StatefulSet) ListImages(ctx context.Context, fqn string) ([]string, error) {
+func (s *StatefulSet) ListImages(_ context.Context, fqn string) ([]string, error) {
 	sts, err := s.GetInstance(s.Factory, fqn)
 	if err != nil {
 		return nil, err
@@ -53,86 +50,17 @@ func (s *StatefulSet) ListImages(ctx context.Context, fqn string) ([]string, err
 
 // Scale a StatefulSet.
 func (s *StatefulSet) Scale(ctx context.Context, path string, replicas int32) error {
-	ns, n := client.Namespaced(path)
-	auth, err := s.Client().CanI(ns, "apps/v1/statefulsets:scale", n, []string{client.GetVerb, client.UpdateVerb})
-	if err != nil {
-		return err
-	}
-	if !auth {
-		return fmt.Errorf("user is not authorized to scale statefulsets")
-	}
-
-	dial, err := s.Client().Dial()
-	if err != nil {
-		return err
-	}
-	scale, err := dial.AppsV1().StatefulSets(ns).GetScale(ctx, n, metav1.GetOptions{})
-	if err != nil {
-		return err
-	}
-	scale.Spec.Replicas = replicas
-	_, err = dial.AppsV1().StatefulSets(ns).UpdateScale(ctx, n, scale, metav1.UpdateOptions{})
-
-	return err
+	return scaleRes(ctx, s.getFactory(), client.StsGVR, path, replicas)
 }
 
 // Restart a StatefulSet rollout.
-func (s *StatefulSet) Restart(ctx context.Context, path string) error {
-	sts, err := s.GetInstance(s.Factory, path)
-	if err != nil {
-		return err
-	}
-
-	ns, n := client.Namespaced(path)
-	pp, err := podsFromSelector(s.Factory, ns, sts.Spec.Selector.MatchLabels)
-	if err != nil {
-		return err
-	}
-	for _, p := range pp {
-		s.Forwarders().Kill(client.FQN(p.Namespace, p.Name))
-	}
-
-	auth, err := s.Client().CanI(sts.Namespace, "apps/v1/statefulsets", n, client.PatchAccess)
-	if err != nil {
-		return err
-	}
-	if !auth {
-		return fmt.Errorf("user is not authorized to restart a statefulset")
-	}
-
-	dial, err := s.Client().Dial()
-	if err != nil {
-		return err
-	}
-
-	before, err := runtime.Encode(scheme.Codecs.LegacyCodec(appsv1.SchemeGroupVersion), sts)
-	if err != nil {
-		return err
-	}
-
-	after, err := polymorphichelpers.ObjectRestarterFn(sts)
-	if err != nil {
-		return err
-	}
-	diff, err := strategicpatch.CreateTwoWayMergePatch(before, after, sts)
-	if err != nil {
-		return err
-	}
-	_, err = dial.AppsV1().StatefulSets(sts.Namespace).Patch(
-		ctx,
-		sts.Name,
-		types.StrategicMergePatchType,
-		diff,
-		metav1.PatchOptions{},
-	)
-
-	return err
-
+func (s *StatefulSet) Restart(ctx context.Context, path string, opts *metav1.PatchOptions) error {
+	return restartRes[*appsv1.StatefulSet](ctx, s.getFactory(), client.StsGVR, path, opts)
 }
 
 // GetInstance returns a statefulset instance.
 func (*StatefulSet) GetInstance(f Factory, fqn string) (*appsv1.StatefulSet, error) {
-	o, err := f.Get("apps/v1/statefulsets", fqn, true, labels.Everything())
+	o, err := f.Get(client.StsGVR, fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -170,7 +98,7 @@ func (s *StatefulSet) Pod(fqn string) (string, error) {
 }
 
 func (s *StatefulSet) getStatefulSet(fqn string) (*appsv1.StatefulSet, error) {
-	o, err := s.getFactory().Get(s.gvrStr(), fqn, true, labels.Everything())
+	o, err := s.getFactory().Get(s.gvr, fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -185,9 +113,9 @@ func (s *StatefulSet) getStatefulSet(fqn string) (*appsv1.StatefulSet, error) {
 }
 
 // ScanSA scans for serviceaccount refs.
-func (s *StatefulSet) ScanSA(ctx context.Context, fqn string, wait bool) (Refs, error) {
+func (s *StatefulSet) ScanSA(_ context.Context, fqn string, wait bool) (Refs, error) {
 	ns, n := client.Namespaced(fqn)
-	oo, err := s.getFactory().List(s.GVR(), ns, wait, labels.Everything())
+	oo, err := s.getFactory().List(s.gvr, ns, wait, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -211,9 +139,9 @@ func (s *StatefulSet) ScanSA(ctx context.Context, fqn string, wait bool) (Refs,
 }
 
 // Scan scans for cluster resource refs.
-func (s *StatefulSet) Scan(ctx context.Context, gvr client.GVR, fqn string, wait bool) (Refs, error) {
+func (s *StatefulSet) Scan(_ context.Context, gvr *client.GVR, fqn string, wait bool) (Refs, error) {
 	ns, n := client.Namespaced(fqn)
-	oo, err := s.getFactory().List(s.GVR(), ns, wait, labels.Everything())
+	oo, err := s.getFactory().List(s.gvr, ns, wait, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -226,7 +154,7 @@ func (s *StatefulSet) Scan(ctx context.Context, gvr client.GVR, fqn string, wait
 			return nil, errors.New("expecting StatefulSet resource")
 		}
 		switch gvr {
-		case CmGVR:
+		case client.CmGVR:
 			if !hasConfigMap(&sts.Spec.Template.Spec, n) {
 				continue
 			}
@@ -234,7 +162,7 @@ func (s *StatefulSet) Scan(ctx context.Context, gvr client.GVR, fqn string, wait
 				GVR: s.GVR(),
 				FQN: client.FQN(sts.Namespace, sts.Name),
 			})
-		case SecGVR:
+		case client.SecGVR:
 			found, err := hasSecret(s.Factory, &sts.Spec.Template.Spec, sts.Namespace, n, wait)
 			if err != nil {
 				slog.Warn("Locate secret failed",
@@ -250,9 +178,9 @@ func (s *StatefulSet) Scan(ctx context.Context, gvr client.GVR, fqn string, wait
 				GVR: s.GVR(),
 				FQN: client.FQN(sts.Namespace, sts.Name),
 			})
-		case PvcGVR:
-			for _, v := range sts.Spec.VolumeClaimTemplates {
-				if !strings.HasPrefix(n, v.Name+"-"+sts.Name) {
+		case client.PvcGVR:
+			for i := range sts.Spec.VolumeClaimTemplates {
+				if !strings.HasPrefix(n, sts.Spec.VolumeClaimTemplates[i].Name+"-"+sts.Name) {
 					continue
 				}
 				refs = append(refs, Ref{
@@ -267,7 +195,7 @@ func (s *StatefulSet) Scan(ctx context.Context, gvr client.GVR, fqn string, wait
 				GVR: s.GVR(),
 				FQN: client.FQN(sts.Namespace, sts.Name),
 			})
-		case PcGVR:
+		case client.PcGVR:
 			if !hasPC(&sts.Spec.Template.Spec, n) {
 				continue
 			}
@@ -275,7 +203,6 @@ func (s *StatefulSet) Scan(ctx context.Context, gvr client.GVR, fqn string, wait
 				GVR: s.GVR(),
 				FQN: client.FQN(sts.Namespace, sts.Name),
 			})
-
 		}
 	}
 
@@ -295,7 +222,7 @@ func (s *StatefulSet) GetPodSpec(path string) (*v1.PodSpec, error) {
 // SetImages sets container images.
 func (s *StatefulSet) SetImages(ctx context.Context, path string, imageSpecs ImageSpecs) error {
 	ns, n := client.Namespaced(path)
-	auth, err := s.Client().CanI(ns, "apps/v1/statefulset", n, client.PatchAccess)
+	auth, err := s.Client().CanI(ns, client.StsGVR, n, client.PatchAccess)
 	if err != nil {
 		return err
 	}
@@ -319,26 +246,3 @@ func (s *StatefulSet) SetImages(ctx context.Context, path string, imageSpecs Ima
 	)
 	return err
 }
-
-func podsFromSelector(f Factory, ns string, sel map[string]string) ([]*v1.Pod, error) {
-	oo, err := f.List("v1/pods", ns, true, labels.Set(sel).AsSelector())
-	if err != nil {
-		return nil, err
-	}
-
-	if len(oo) == 0 {
-		return nil, fmt.Errorf("no matching pods for %v", sel)
-	}
-
-	pp := make([]*v1.Pod, 0, len(oo))
-	for _, o := range oo {
-		pod := new(v1.Pod)
-		err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, pod)
-		if err != nil {
-			return nil, err
-		}
-		pp = append(pp, pod)
-	}
-
-	return pp, nil
-}
