@@ -11,6 +11,7 @@ import (
 	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestScreenDumpRender(t *testing.T) {
@@ -21,7 +22,7 @@ func TestScreenDumpRender(t *testing.T) {
 		Dir:  "fred/blee",
 	}
 
-	assert.Nil(t, s.Render(o, "fred", &r))
+	require.NoError(t, s.Render(o, "fred", &r))
 	assert.Equal(t, "fred/blee/bob", r.ID)
 	assert.Equal(t, model1.Fields{
 		"bob",
@@ -36,9 +37,12 @@ type fileInfo struct{}
 
 var _ os.FileInfo = fileInfo{}
 
-func (f fileInfo) Name() string       { return "bob" }
-func (f fileInfo) Size() int64        { return 100 }
-func (f fileInfo) Mode() os.FileMode  { return os.FileMode(0644) }
-func (f fileInfo) ModTime() time.Time { return testTime() }
-func (f fileInfo) IsDir() bool        { return false }
-func (f fileInfo) Sys() interface{}   { return nil }
+func (fileInfo) Name() string       { return "bob" }
+func (fileInfo) Size() int64        { return 100 }
+func (fileInfo) ModTime() time.Time { return testTime() }
+func (fileInfo) IsDir() bool        { return false }
+func (fileInfo) Sys() any           { return nil }
+
+func (fileInfo) Mode() os.FileMode {
+	return os.FileMode(0644)
+}
