@@ -24,7 +24,7 @@ type ValueExtender struct {
 func NewValueExtender(r ResourceViewer) ResourceViewer {
 	p := ValueExtender{ResourceViewer: r}
 	p.AddBindKeysFn(p.bindKeys)
-	p.GetTable().SetEnterFn(func(app *App, model ui.Tabular, gvr client.GVR, path string) {
+	p.GetTable().SetEnterFn(func(*App, ui.Tabular, *client.GVR, string) {
 		p.valuesCmd(nil)
 	})
 
@@ -49,13 +49,13 @@ func (v *ValueExtender) defaultCtx() context.Context {
 	return context.WithValue(context.Background(), internal.KeyFactory, v.App().factory)
 }
 
-func showValues(ctx context.Context, app *App, path string, gvr client.GVR) {
+func showValues(ctx context.Context, app *App, path string, gvr *client.GVR) {
 	vm := model.NewValues(gvr, path)
 	if err := vm.Init(app.factory); err != nil {
 		app.Flash().Errf("Initializing the values model failed: %s", err)
 	}
 
-	toggleValuesCmd := func(evt *tcell.EventKey) *tcell.EventKey {
+	toggleValuesCmd := func(*tcell.EventKey) *tcell.EventKey {
 		if err := vm.ToggleValues(); err != nil {
 			app.Flash().Errf("Values toggle failed: %s", err)
 			return nil
