@@ -9,7 +9,6 @@ import (
 	"log/slog"
 	"regexp"
 	"strings"
-	"time"
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
@@ -57,9 +56,9 @@ func NewXray(gvr *client.GVR) ResourceViewer {
 	}
 }
 
-func (*Xray) SetCommand(*cmd.Interpreter)      {}
-func (*Xray) SetFilter(string)                 {}
-func (*Xray) SetLabelSelector(labels.Selector) {}
+func (*Xray) SetCommand(*cmd.Interpreter)            {}
+func (*Xray) SetFilter(string, bool)                 {}
+func (*Xray) SetLabelSelector(labels.Selector, bool) {}
 
 // Init initializes the view.
 func (x *Xray) Init(ctx context.Context) error {
@@ -87,7 +86,7 @@ func (x *Xray) Init(ctx context.Context) error {
 	x.SetGraphicsColor(x.app.Styles.Xray().GraphicColor.Color())
 	x.SetTitle(fmt.Sprintf(" %s-%s ", xrayTitle, cases.Title(language.Und, cases.NoLower).String(x.gvr.R())))
 
-	x.model.SetRefreshRate(time.Duration(x.app.Config.K9s.GetRefreshRate()) * time.Second)
+	x.model.SetRefreshRate(x.app.Config.K9s.RefreshDuration())
 	x.model.SetNamespace(client.CleanseNamespace(x.app.Config.ActiveNamespace()))
 	x.model.AddListener(x)
 
@@ -612,7 +611,7 @@ func (x *Xray) defaultContext() context.Context {
 	if x.CmdBuff().Empty() {
 		ctx = context.WithValue(ctx, internal.KeyLabels, labels.Everything())
 	} else {
-		if sel, err := ui.TrimLabelSelector(x.CmdBuff().GetText()); err == nil {
+		if sel, err := ui.ExtractLabelSelector(x.CmdBuff().GetText()); err == nil {
 			ctx = context.WithValue(ctx, internal.KeyLabels, sel)
 		}
 	}
@@ -691,7 +690,7 @@ func (x *Xray) styleTitle() string {
 		return title
 	}
 	if internal.IsLabelSelector(buff) {
-		if sel, err := ui.TrimLabelSelector(buff); err == nil {
+		if sel, err := ui.ExtractLabelSelector(buff); err == nil {
 			buff = sel.String()
 		}
 	}
