@@ -8,8 +8,10 @@ import (
 	"testing"
 
 	"github.com/derailed/k9s/internal"
+	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/xray"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
@@ -30,15 +32,15 @@ func TestDaemonSetRender(t *testing.T) {
 	var re xray.DaemonSet
 	for k := range uu {
 		f := makeFactory()
-		f.rows = map[string][]runtime.Object{"v1/pods": {load(t, "po")}}
+		f.rows = map[*client.GVR][]runtime.Object{client.PodGVR: {load(t, "po")}}
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
 			o := load(t, u.file)
-			root := xray.NewTreeNode("daemonsets", "daemonsets")
+			root := xray.NewTreeNode(client.DsGVR, "daemonsets")
 			ctx := context.WithValue(context.Background(), xray.KeyParent, root)
 			ctx = context.WithValue(ctx, internal.KeyFactory, f)
 
-			assert.Nil(t, re.Render(ctx, "", o))
+			require.NoError(t, re.Render(ctx, "", o))
 			assert.Equal(t, u.level1, root.CountChildren())
 			assert.Equal(t, u.level2, root.Children[0].CountChildren())
 		})
