@@ -22,7 +22,7 @@ func (g *Generic) SetTable(_ string, t *metav1.Table) {
 }
 
 // Render renders a K8s resource to screen.
-func (g *Generic) Render(ctx context.Context, ns string, o interface{}) error {
+func (g *Generic) Render(ctx context.Context, ns string, o any) error {
 	row, ok := o.(metav1.TableRow)
 	if !ok {
 		return fmt.Errorf("expecting a TableRow but got %T", o)
@@ -33,7 +33,7 @@ func (g *Generic) Render(ctx context.Context, ns string, o interface{}) error {
 		return fmt.Errorf("expecting row 0 to be a string but got %T", row.Cells[0])
 	}
 
-	root := NewTreeNode("generic", client.FQN(ns, n))
+	root := NewTreeNode(client.NewGVR("generic"), client.FQN(ns, n))
 	parent, ok := ctx.Value(KeyParent).(*TreeNode)
 	if !ok {
 		return fmt.Errorf("expecting TreeNode but got %T", ctx.Value(KeyParent))
